# tda-api-vol
Uses TDA API in order to scrape data with a main focus on implied volatility surfaces as well as option greeks.


![image](https://user-images.githubusercontent.com/75052782/209724422-2016c159-7053-4872-b611-f80e0dae0188.png)
